Python PEMicro debug probes support
===================================

This is simple package that provides Python interface for PEMicro debug probes precompiled libraries. The package provides most of functionality 
of the PEMicro libraries and their debug probes.

The package is tested only with Multilink/FX and Cyclone/FX probes on NXP ARM microcontrollers.

The PEMicro company helps with this development, so big Thanks to them (www.pemicro.com).

Author: Petr Gargulak (NXP 2020-2021, www.nxp.com)

Dependencies
------------

There is no dependencies


Installation
------------
Directly from www.pypi.org:

``` bash
    $ pip install pypemicro
